Function ecli_lib::oci::parse_img_url
source · pub fn parse_img_url(
url: &str
) -> Result<(Client, RegistryAuth, Reference, String)>Expand description
Ex-export some helper functions from wasm module Parse the URL, return things that will be used for pushing / pulling returns (…, repo_url_strip_auth_info)